# Generated by Django 5.1.6 on 2026-02-08 15:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfchelseru', '0023_chatroom_updated_at_messagechat_read_by'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messagechat',
            name='read_by',
            field=models.ManyToManyField(blank=True, related_name='read_messages_drf_chelseru', to='drfchelseru.user'),
        ),
    ]
