# Generated by Django 5.1.6 on 2025-08-28 20:03

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfchelseru', '0018_alter_payment_ref_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='payment',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='payment',
            name='status',
            field=models.CharField(choices=[('paid', 'paid'), ('unpaid', 'unpaid'), ('canceled', 'canceled'), ('refounded', 'refounded')], default='unpaid', max_length=15),
        ),
        migrations.AddField(
            model_name='payment',
            name='updated_at',
            field=models.DateTimeField(auto_now=True),
        ),
    ]
