# Generated by Django 5.1.6 on 2025-08-28 09:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("drfchelseru", "0017_alter_payment_callback_url_alter_payment_gateway_url"),
    ]

    operations = [
        migrations.AlterField(
            model_name="payment",
            name="ref_id",
            field=models.BigIntegerField(blank=True, null=True),
        ),
    ]
