# Generated by Django 5.1.6 on 2025-08-16 09:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("drfchelseru", "0008_alter_chatroompermissions_user"),
    ]

    operations = [
        migrations.AlterField(
            model_name="chatroom",
            name="status",
            field=models.IntegerField(
                default=1, verbose_name=[(1, "Open"), (2, "Close"), (3, "Hold")]
            ),
        ),
    ]
