# Generated by Django 5.1.6 on 2025-08-26 21:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfchelseru', '0015_payment_message'),
    ]

    operations = [
        migrations.AddField(
            model_name='payment',
            name='card_hash',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='card_pan',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='data_verify',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='ref_id',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
