# Generated by Django 5.1.6 on 2025-08-26 21:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfchelseru', '0014_payment_gateway_title_payment_gateway_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='payment',
            name='message',
            field=models.CharField(blank=True, max_length=25, null=True),
        ),
    ]
