# Generated by Django 5.1.6 on 2026-02-06 15:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("drfchelseru", "0022_payment_pay_mode_wallet"),
    ]

    operations = [
        migrations.AddField(
            model_name="chatroom",
            name="updated_at",
            field=models.DateTimeField(auto_now=True),
        ),
        migrations.AddField(
            model_name="messagechat",
            name="read_by",
            field=models.ManyToManyField(
                blank=True, related_name="read_messages", to="drfchelseru.user"
            ),
        ),
    ]
