# Generated by Django 5.1.6 on 2025-08-14 19:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('drfchelseru', '0003_rename_mobile_otpcode_mobile_number'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Message',
            new_name='Message_SMS',
        ),
    ]
