# Generated by Django 5.1.6 on 2025-08-28 07:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("drfchelseru", "0016_payment_card_hash_payment_card_pan_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="payment",
            name="callback_url",
            field=models.URLField(),
        ),
        migrations.AlterField(
            model_name="payment",
            name="gateway_url",
            field=models.URLField(blank=True, null=True),
        ),
    ]
